package com.hzya.frame.grpU8.nxproof.attachment.entity;/*
* @Description 附件表
* @Author xiangerlin 
  @Date 2022-10-26 10:40
*/


import com.hzya.frame.web.entity.BaseEntity;

public class AttachmentFileEntity  extends BaseEntity {

   private String aTGuid;//主键id
   private String createDate;//创建日期
   private String createID;//创建人id
   private String updateDate;//更新日期
   private String updateID;//更新人id
   private String deleteDate;//删除日期
   private String deleteID;//删除人
   private String aTFileName;//附件名
   private String aTExtName;//附件后缀名
   private byte[] aTFile;//附件 二进制文件
   private String relationApp;//固定传 OER
   private String isDELETE;//删除标记 0是未删除

    public String getaTGuid() {
        return aTGuid;
    }

    public void setaTGuid(String aTGuid) {
        this.aTGuid = aTGuid;
    }

    public String getCreateDate() {
        return createDate;
    }

    public void setCreateDate(String createDate) {
        this.createDate = createDate;
    }

    public String getCreateID() {
        return createID;
    }

    public void setCreateID(String createID) {
        this.createID = createID;
    }

    public String getUpdateDate() {
        return updateDate;
    }

    public void setUpdateDate(String updateDate) {
        this.updateDate = updateDate;
    }

    public String getUpdateID() {
        return updateID;
    }

    public void setUpdateID(String updateID) {
        this.updateID = updateID;
    }

    public String getDeleteDate() {
        return deleteDate;
    }

    public void setDeleteDate(String deleteDate) {
        this.deleteDate = deleteDate;
    }

    public String getDeleteID() {
        return deleteID;
    }

    public void setDeleteID(String deleteID) {
        this.deleteID = deleteID;
    }

    public String getaTFileName() {
        return aTFileName;
    }

    public void setaTFileName(String aTFileName) {
        this.aTFileName = aTFileName;
    }

    public String getaTExtName() {
        return aTExtName;
    }

    public void setaTExtName(String aTExtName) {
        this.aTExtName = aTExtName;
    }

    public byte[] getaTFile() {
        return aTFile;
    }

    public void setaTFile(byte[] aTFile) {
        this.aTFile = aTFile;
    }

    public String getRelationApp() {
        return relationApp;
    }

    public void setRelationApp(String relationApp) {
        this.relationApp = relationApp;
    }

    public String getIsDELETE() {
        return isDELETE;
    }

    public void setIsDELETE(String isDELETE) {
        this.isDELETE = isDELETE;
    }
}
